# L3C - Life Long Learning In Context

L3C provide abundant environments for Lifelong Learning (L3) in Context.

In-Context Learning entails a different learning process than that of gradient descent, as it involves feeding data through prompts instead. Our objective is to enhance lifelong learning research by utilizing prompts, which involve agents that learn through interaction in a forward-only manner.

# Environments Updating

- [MazeWorlds](l3c/mazeworld): 2D/3D maze generators for task generalization

- [MetaLM](l3c/metalm): Meta language model dataset

- [Bandits](l3c/bandits): Bandits task generalization
